@@ -96,7 +96,7 @@ def main():
     a_logger.debug(f'Functional was predicted for {predicted_persentage}% of all fungies.')
     
     # Generation output 
-    Result['Function'] = Ortology_group
+    Meta_micom['Function'] = Ortology_group
     Meta_micom = DataFrame(Meta_micom).set_index('Function')
     Meta_micom = Meta_micom.assign(m=Meta_micom.mean(axis=1)).sort_values('m').drop('m', axis=1)
     fig = px.bar(Meta_micom.T, x=Meta_micom.columns, y=Meta_micom.index, width=1500, height=1000)
